﻿using PPPISI52.Windows;
using System;
using System.Collections.Generic;
using System.Data.Entity.Core.Common.CommandTrees.ExpressionBuilder;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace PPPISI52.Pages
{
    /// <summary>
    /// Логика взаимодействия для MainUserPage.xaml
    /// </summary>
    public partial class MainUserPage : Page
    {
        List<Product> products = new List<Product>();
        User current_user;
        int all_items;
        int showed_items;


        public MainUserPage()
        {
            InitializeComponent();
            DefaultData();
        }

        public MainUserPage(User user)
        {
            InitializeComponent();
            PP_PISIEntities DB = new PP_PISIEntities();
            LVProducts.ItemsSource = DB.Product.ToList();

            current_user = user;
            DefaultData();
            
            List<Order> orders = Base.MyBase.Order.Where(x => x.UserID == user.UserID).ToList();
            if (orders.Count > 0)
            {
                BAddProduct.Visibility = Visibility.Visible;
            }
            
            List<ProductCategory> rl = DB.ProductCategory.ToList();
            CBDiscount.Items.Add("Все отделы");
            foreach (ProductCategory i in rl)
            {
                CBDiscount.Items.Add(i.CategoryTitle);
            }
            CBDiscount.SelectedIndex = 0;

        }

        public void Filter()
        {
            PP_PISIEntities DB = new PP_PISIEntities();
            List<Product> prFilter = new List<Product>();
            List<ProductCategory> rl = DB.ProductCategory.ToList();
            if (CBDiscount.SelectedIndex != 0)
            {
                List<ProductCategory> aut = DB.ProductCategory.ToList();
                int index = Convert.ToInt32(aut.Where(x => x.CategoryID == CBDiscount.SelectedIndex).Select(x => x.CategoryID).FirstOrDefault());
                prFilter = DB.Product.Where(x => x.ProductCategory == index).ToList();
            }
            else
            {
                prFilter = DB.Product.ToList();
            }


            LVProducts.ItemsSource = prFilter;
        }

        private void DefaultData()
        {
            products = Base.MyBase.Product.ToList();
            LVProducts.ItemsSource = products;

            CBDiscount.SelectedIndex = 0;
            
            all_items = products.Count;
            showed_items = products.Count;
            TBItems.Text = showed_items + "/" + all_items;
            
            TBSearch.Text = "";
        }

     

       

       

        

        private void Sort()
        {
            products = Base.MyBase.Product.ToList();

            if (TBSearch.Text.Length > 0)
            {
                products = products.Where(x => x.ProductName.ToLower().Contains(TBSearch.Text.ToLower())).ToList();
            }
            switch (CBDiscount.SelectedIndex)
            {
                case 0: break;
                case 1: products = products.Where(x => Convert.ToInt32(x.ProductDiscountAmount) < 10).ToList(); break;
                case 2: products = products.Where(x => Convert.ToInt32(x.ProductDiscountAmount) < 15).ToList(); break;
                case 3: products = products.Where(x => Convert.ToInt32(x.ProductDiscountAmount) >= 15).ToList(); break;
                default: break;
            }

           

           

            showed_items = products.Count();
            TBItems.Text = showed_items + "/" + all_items;

            LVProducts.ItemsSource = products;
        }

        

        private void Search_TextChanged(object sender, TextChangedEventArgs e)
        {
            Sort();
        }

        private void RadioButton_Checked(object sender, RoutedEventArgs e)
        {
            Sort();
        }

        private void ComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            Sort();
        }
        private void CBFilterBreed_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            Filter();
        }



        private void ContextMenu_Loaded(object sender, RoutedEventArgs e)
        {
            ContextMenu cm = (ContextMenu)sender;
            if (current_user == null) cm.Visibility = Visibility.Collapsed;
        }

        private void EditProduct_Loaded(object sender, RoutedEventArgs e)
        {
            MenuItem menuItem = (MenuItem)sender;
            if (current_user == null );
        }

        private void DeleteProduct_Loaded(object sender, RoutedEventArgs e)
        {
            MenuItem menuItem = (MenuItem)sender;
            if (current_user == null );
        }

        private void EditProduct_Click(object sender, RoutedEventArgs e)
        {
            AddChangeProductWindow addChangeProductWindow = new AddChangeProductWindow((Product)LVProducts.SelectedItem);
            addChangeProductWindow.ShowDialog();
            DefaultData();
        }

        private void DeleteProduct_Click(object sender, RoutedEventArgs e)
        {
            MessageBoxResult mbr = MessageBox.Show("Удалить картридж?", "Удаление", MessageBoxButton.YesNo, MessageBoxImage.Question);
            if (mbr == MessageBoxResult.Yes)
            {
                try
                {
                    Base.MyBase.Product.Remove((Product)LVProducts.SelectedItem);
                    Base.MyBase.SaveChanges();
                    MessageBox.Show("Картртдж удален", "Успешно", MessageBoxButton.OK, MessageBoxImage.Information);
                    DefaultData();
                }
                catch
                {
                    MessageBox.Show("Ошибка. Картридж не может быть удален.", "Оповещение", MessageBoxButton.OK, MessageBoxImage.Error);
                }
            }
        }

        int id_new_order = Base.MyBase.Order.Max(x => x.OrderID) + 1;
        private void AddOrder_Click(object sender, RoutedEventArgs e)
        {
            Product product = (Product)LVProducts.SelectedItem;
            try
            {
                OrderProduct exist_op = Base.MyBase.OrderProduct.FirstOrDefault(x => x.ProductArticleNumber == product.ProductArticleNumber && x.Order.OrderStatus == 2);
                Order exist_order = Base.MyBase.Order.FirstOrDefault(x => x.UserID == current_user.UserID && x.OrderID == exist_op.OrderID);
                if (exist_order != null)
                {
                    MessageBox.Show("Картридж уже добавлен. Отредактируйте количество.", "Картридж существует");
                }
                else
                {
                    OrderProduct op = new OrderProduct();
                    if (Base.MyBase.Order.Max(x => x.OrderID) < id_new_order)
                    {
                        Order new_order = new Order();
                        new_order.OrderID = id_new_order;
                        new_order.OrderStatus = 2;
                        new_order.OrderDate = DateTime.Now;
                        new_order.OrderDeliveryDate = DateTime.Now.AddDays(3);
                        new_order.OrderPickUpPoint = 1;
                        new_order.UserID = current_user.UserID;
                        new_order.Code = Base.MyBase.Order.Max(x => x.Code) + 1;
                        Base.MyBase.Order.Add(new_order);
                    }
                    op.OrderID = id_new_order;
                    op.ProductArticleNumber = product.ProductArticleNumber;
                    op.ProductCount = 1;
                    Base.MyBase.OrderProduct.Add(op);
                    Base.MyBase.SaveChanges();
                    
                }
            }
            catch { }
        }

        private void AddNewProduct_Click(object sender, RoutedEventArgs e)
        {
            AddChangeProductWindow addChangeProductWindow = new AddChangeProductWindow();
            addChangeProductWindow.ShowDialog();
            DefaultData();
        }
    }
}

