﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

namespace PPPISI52.Windows
{
    /// <summary>
    /// Логика взаимодействия для AddChangeProductWindow.xaml
    /// </summary>
    public partial class AddChangeProductWindow : Window
    {
        Product new_product;
        List<string> categories = new List<string>();
        List<string> providers = new List<string>();
        List<string> manufacturers = new List<string>();
        bool isNew = false;
        public AddChangeProductWindow()
        {
            InitializeComponent();
            isNew = true;
            new_product = new Product();
            DataLoaded();
            BAddChange.Content = "Добавить";
        }

        public AddChangeProductWindow(Product product)
        {
            InitializeComponent();
            new_product = product;
            DataLoaded();
        }

        private void DataLoaded()
        {
            categories.AddRange(Base.MyBase.ProductCategory.Select(x => x.CategoryTitle));
            providers.AddRange(Base.MyBase.Provider.Select(x => x.Provider1));
            manufacturers.AddRange(Base.MyBase.Manufacturer.Select(x => x.Manufacturer1));
            CBProductCategory.ItemsSource = categories;
            CBProductManufacturer.ItemsSource = manufacturers;
            CBProductProvider.ItemsSource = providers;
            if (!isNew)
            {
                if (new_product.ProductPhoto != null)
                {
                    IPhoto.Source = new BitmapImage(new Uri(new_product.ProductPhoto, UriKind.Relative));
                }
                TBProductArticleNumber.Text = new_product.ProductArticleNumber;
                TBProductName.Text = new_product.ProductName;
                TBProductDescription.Text = new_product.ProductDescription;
                CBProductCategory.SelectedIndex = categories.IndexOf(Base.MyBase.ProductCategory.FirstOrDefault(x => x.CategoryID == new_product.ProductCategory).CategoryTitle);
                CBProductManufacturer.SelectedIndex = manufacturers.IndexOf(Base.MyBase.Manufacturer.FirstOrDefault(x => x.ManufacturerID == new_product.ProductManufacturer).Manufacturer1);
                CBProductProvider.SelectedIndex = providers.IndexOf(Base.MyBase.Provider.FirstOrDefault(x => x.ProviderID == new_product.ProductProvider).Provider1);
                
                TBProductInStock.Text = new_product.ProductQuantityInStock.ToString();
            }
        }

        private void CBProductCategory_Changed(object sender, SelectionChangedEventArgs e)
        {
            new_product.ProductCategory = Base.MyBase.ProductCategory.FirstOrDefault(x => x.CategoryTitle == CBProductCategory.SelectedValue.ToString()).CategoryID;
        }

        private void CBProductManufacturer_Changed(object sender, SelectionChangedEventArgs e)
        {
            new_product.ProductManufacturer = Base.MyBase.Manufacturer.FirstOrDefault(x => x.Manufacturer1 == CBProductManufacturer.SelectedValue.ToString()).ManufacturerID;
        }

        private void CBProductProvider_Changed(object sender, SelectionChangedEventArgs e)
        {
            new_product.ProductProvider = Base.MyBase.Provider.FirstOrDefault(x => x.Provider1 == CBProductProvider.SelectedValue.ToString()).ProviderID;
        }

        private bool CheckingData()
        {
            if ((Base.MyBase.Product.FirstOrDefault(x => x.ProductArticleNumber.ToString() == TBProductArticleNumber.Text) != null) && (isNew))
            {
                MessageBox.Show("Товар с таким артикулом уже существует!", "Невозможно внести изменения");
                return false;
            }
            if ((TBProductName.Text.Length <= 0) || (TBProductDescription.Text.Length <= 0) || (CBProductCategory.SelectedIndex < 0) || (CBProductManufacturer.SelectedIndex < 0) || (CBProductProvider.SelectedIndex < 0))
            {
                MessageBox.Show("Все поля, кроме скидки и количества на складе должны быть заполнены!", "Невозможно внести изменения");
                return false;
            }
          
            try
            {
                if ((Convert.ToInt32(TBProductInStock.Text) < 0))
                {
                    MessageBox.Show("Цена, размер скидки и количества на складе не могут быть отрицательны!", "Невозможно внести изменения");
                    return false;
                }
            }
            catch { }
            return true;
        }

        private void GetNewData()
        {
            new_product.ProductArticleNumber = TBProductArticleNumber.Text;
            new_product.ProductName = TBProductName.Text;
            new_product.ProductDescription = TBProductDescription.Text;
            if ((new_product.ProductPhoto == null) || (new_product.ProductPhoto == "/Photos/picture.png"))
            {
                new_product.ProductPhoto = "";
            }
            
        
            
            try
            {
                new_product.ProductQuantityInStock = Convert.ToInt32(TBProductInStock.Text);
            }
            catch { }
        }

        private void AddChange_Click(object sender, RoutedEventArgs e)
        {
            if (CheckingData())
            {
                GetNewData();
                if (isNew)
                {
                    Base.MyBase.Product.Add(new_product);
                }
                Base.MyBase.SaveChanges();
                this.Close();
            }
        }

        private void Cancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        private void UpdatePhoto_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            openFileDialog.ShowDialog();
            new_product.ProductPhoto = "/Photos/" + openFileDialog.FileName.Substring(openFileDialog.FileName.LastIndexOf("\\")).Replace("\\", "");
            IPhoto.Source = new BitmapImage(new Uri(new_product.ProductPhoto, UriKind.Relative));
        }
    }
}
